pub enum ReExportImportName {
Name(Sym),
Star,
}Expand description
The name under which a reexported binding is exported by a module.
This differs slightly from the spec, since [[ImportName]] can be either a name, all-but-default
or all, but the last two exports can be identified with the export_name field from
ExportEntry, which joins both variants into a single Star variant.
Variants