pub struct ExportSpecifier { /* private fields */ }Expand description
Implementations
Sourceimpl ExportSpecifier
impl ExportSpecifier
Sourcepub const fn new(alias: Sym, private_name: Sym, string_literal: bool) -> Self
pub const fn new(alias: Sym, private_name: Sym, string_literal: bool) -> Self
Creates a new ExportSpecifier.
Sourcepub const fn private_name(self) -> Sym
pub const fn private_name(self) -> Sym
Gets the private name of the export inside the module.
Sourcepub const fn string_literal(&self) -> bool
pub const fn string_literal(&self) -> bool
Returns true if the private name of the specifier was a StringLiteral.