pub struct ImportAttribute { /* private fields */ }Expand description
An import attribute entry in an ImportDeclaration.
This is a key-value pair, where the key is an identifier or string literal, and the value is a string literal.
More information:
Implementations