LogicalOp

Enum LogicalOp 

pub enum LogicalOp {
    And,
    Or,
    Coalesce,
}
Logical operators are typically used with Boolean (logical) values; when they are, they return a Boolean value.

However, the && and || operators actually return the value of one of the specified operands, so if these operators are used with non-Boolean values, they may return a non-Boolean value.

More information:

Variants



And

The logical AND operator returns the value of the first operand if it can be coerced into false; otherwise, it returns the second operand.

Syntax: x && y

More information:



Or

The logical OR operator returns the value the first operand if it can be coerced into true; otherwise, it returns the second operand.

Syntax: x || y

More information:



Coalesce

The nullish coalescing operator is a logical operator that returns the second operand when its first operand is null or undefined, and otherwise returns its first operand.

Syntax: x ?? y

More information: