Binary

Struct Binary 

pub struct Binary { /* private fields */ }
Binary operations require two operands, one before the operator and one after the operator.

See the module level documentation for more information.

Implementations

Source

impl Binary

pub fn new(op: BinaryOp, lhs: Expression, rhs: Expression) -> Self

Creates a BinOp AST Expression.

pub const fn op(&self) -> BinaryOp

Gets the binary operation of the Expression.

pub const fn lhs(&self) -> &Expression

Gets the left hand side of the binary operation.

pub const fn rhs(&self) -> &Expression

Gets the right hand side of the binary operation.

pub fn lhs_mut(&mut self) -> &mut Expression

Gets the left hand side of the binary operation.

pub fn rhs_mut(&mut self) -> &mut Expression

Gets the right hand side of the binary operation.