pub struct BinaryInPrivate { /* private fields */ }Expand description
Binary relational In expression with a private name on the left hand side.
Because the left hand side must be a private name, this is a separate type from Binary.
Implementations
Sourceimpl BinaryInPrivate
impl BinaryInPrivate
Sourcepub fn new(lhs: PrivateName, rhs: Expression) -> Self
pub fn new(lhs: PrivateName, rhs: Expression) -> Self
Creates a BinaryInPrivate AST Expression.
Sourcepub const fn lhs(&self) -> &PrivateName
pub const fn lhs(&self) -> &PrivateName
Gets the left hand side of the binary operation.
Sourcepub const fn rhs(&self) -> &Expression
pub const fn rhs(&self) -> &Expression
Gets the right hand side of the binary operation.