pub struct Conditional { /* private fields */ }Expand description
The conditional (ternary) operation is the only ECMAScript operation that takes three
operands.
This operation takes three operands: a condition followed by a question mark (?),
then an expression to execute if the condition is truthy followed by a colon (:),
and finally the expression to execute if the condition is false.
This operator is frequently used as a shortcut for the if statement.
More information:
Implementations
Sourceimpl Conditional
impl Conditional
Sourcepub const fn condition(&self) -> &Expression
pub const fn condition(&self) -> &Expression
Gets the condition of the Conditional expression.
Sourcepub const fn if_true(&self) -> &Expression
pub const fn if_true(&self) -> &Expression
Gets the expression returned if condition is truthy.
Sourcepub const fn if_false(&self) -> &Expression
pub const fn if_false(&self) -> &Expression
Gets the expression returned if condition is falsy.
Sourcepub fn new(
condition: Expression,
if_true: Expression,
if_false: Expression,
) -> Self
pub fn new( condition: Expression, if_true: Expression, if_false: Expression, ) -> Self
Creates a Conditional AST Expression.