pub struct Call { /* private fields */ }Expand description
Calling the function actually performs the specified actions with the indicated parameters.
Defining a function does not execute it. Defining it simply names the function and specifies what to do when the function is called. Functions must be in scope when they are called, but the function declaration can be hoisted. The scope of a function is the function in which it is declared (or the entire program, if it is declared at the top level).
More information:
Implementations
Sourceimpl Call
impl Call
Sourcepub fn new(function: Expression, args: Box<[Expression]>, span: Span) -> Self
pub fn new(function: Expression, args: Box<[Expression]>, span: Span) -> Self
Creates a new Call AST Expression.
Sourcepub const fn function(&self) -> &Expression
pub const fn function(&self) -> &Expression
Gets the target function of this call expression.
Sourcepub const fn args(&self) -> &[Expression]
pub const fn args(&self) -> &[Expression]
Retrieves the arguments passed to the function.