Identifier

Struct Identifier 

pub struct Identifier { /* private fields */ }
An identifier is a sequence of characters in the code that identifies a variable, function, or property.

In ECMAScript, identifiers are case-sensitive and can contain Unicode letters, $, _, and digits (0-9), but may not start with a digit.

An identifier differs from a string in that a string is data, while an identifier is part of the code. In JavaScript, there is no way to convert identifiers to strings, but sometimes it is possible to parse strings into identifiers.

More information:

Implementations

Source

impl Identifier

pub const fn new(ident: Sym, span: Span) -> Self

Creates a new identifier AST Expression.

pub const fn sym(self) -> Sym

Retrieves the identifier’s string symbol in the interner.

pub const fn sym_ref(&self) -> &Sym

Retrieves the identifier’s string symbol in the interner.

pub const fn sym_mut(&mut self) -> &mut Sym

Retrieves the identifier’s string symbol in the interner.