Spread

Struct Spread 

pub struct Spread { /* private fields */ }
The spread operator allows an iterable such as an array expression or string to be expanded.

Syntax: ...x

It expands array expressions or strings in places where zero or more arguments (for function calls) or elements (for array literals) are expected, or an object expression to be expanded in places where zero or more key-value pairs (for object literals) are expected.

More information:

Implementations

Source

impl Spread

pub fn new(target: Expression, span: Span) -> Self

Creates a Spread AST Expression.

pub const fn target(&self) -> &Expression

Gets the target expression to be expanded by the spread operator.