TaggedTemplate

Struct TaggedTemplate 

pub struct TaggedTemplate { /* private fields */ }
A TaggedTemplate expression, as defined by the spec.

TaggedTemplates are a type of template literals that are parsed by a custom function to generate arbitrary objects from the inner strings and expressions.

Implementations

Source

impl TaggedTemplate

pub fn new( tag: Expression, raws: Box<[Sym]>, cookeds: Box<[Option<Sym>]>, exprs: Box<[Expression]>, identifier: u64, span: Span, ) -> Self

Creates a new tagged template with a tag, the list of raw strings, the cooked strings and the expressions.

pub const fn tag(&self) -> &Expression

Gets the tag function of the template.

pub const fn raws(&self) -> &[Sym]

Gets the inner raw strings of the template.

pub const fn cookeds(&self) -> &[Option<Sym>]

Gets the cooked strings of the template.

pub const fn exprs(&self) -> &[Expression]

Gets the interpolated expressions of the template.

pub const fn identifier(&self) -> u64

Gets the unique identifier of the template.