Yield

Struct Yield 

pub struct Yield { /* private fields */ }
The yield keyword is used to pause and resume a generator function

More information:

Implementations

Source

impl Yield

pub fn new(expr: Option<Expression>, delegate: bool, span: Span) -> Self

Creates a Yield AST Expression.

pub fn target(&self) -> Option<&Expression>

Gets the target expression of this Yield statement.

pub const fn delegate(&self) -> bool

Returns true if this Yield statement delegates to another generator or iterable object.