ArrowFunction

Struct ArrowFunction 

pub struct ArrowFunction { /* private fields */ }
An arrow function expression, as defined by the spec.

An arrow function expression is a syntactically compact alternative to a regular function expression. Arrow function expressions are ill suited as methods, and they cannot be used as constructors. Arrow functions cannot be used as constructors and will throw an error when used with new.

Implementations

Source

impl ArrowFunction

pub fn new( name: Option<Identifier>, parameters: FormalParameterList, body: FunctionBody, linear_span: LinearSpan, span: Span, ) -> Self

Creates a new ArrowFunctionDecl AST Expression.

pub const fn name(&self) -> Option<Identifier>

Gets the name of the arrow function.

pub fn set_name(&mut self, name: Option<Identifier>)

Sets the name of the arrow function.

pub const fn parameters(&self) -> &FormalParameterList

Gets the list of parameters of the arrow function.

pub const fn body(&self) -> &FunctionBody

Gets the body of the arrow function.

pub const fn scopes(&self) -> &FunctionScopes

Returns the scopes of the arrow function.

pub const fn linear_span(&self) -> LinearSpan

Gets linear span of the function declaration.

pub const fn contains_direct_eval(&self) -> bool

Returns true if the arrow function contains a direct call to eval.