pub struct AsyncArrowFunction { /* private fields */ }Expand description
An async arrow function expression, as defined by the spec.
An async arrow function expression is a syntactically compact alternative to a regular function expression. Arrow function expressions are ill suited as methods, and they cannot be used as constructors. Arrow functions cannot be used as constructors and will throw an error when used with new.
Implementations
Sourceimpl AsyncArrowFunction
impl AsyncArrowFunction
Sourcepub fn new(
name: Option<Identifier>,
parameters: FormalParameterList,
body: FunctionBody,
linear_span: LinearSpan,
span: Span,
) -> Self
pub fn new( name: Option<Identifier>, parameters: FormalParameterList, body: FunctionBody, linear_span: LinearSpan, span: Span, ) -> Self
Creates a new AsyncArrowFunction AST Expression.
Sourcepub const fn name(&self) -> Option<Identifier>
pub const fn name(&self) -> Option<Identifier>
Gets the name of the async arrow function.
Sourcepub fn set_name(&mut self, name: Option<Identifier>)
pub fn set_name(&mut self, name: Option<Identifier>)
Sets the name of the async arrow function.
Sourcepub const fn parameters(&self) -> &FormalParameterList
pub const fn parameters(&self) -> &FormalParameterList
Gets the list of parameters of the async arrow function.
Sourcepub const fn body(&self) -> &FunctionBody
pub const fn body(&self) -> &FunctionBody
Gets the body of the async arrow function.
Sourcepub const fn scopes(&self) -> &FunctionScopes
pub const fn scopes(&self) -> &FunctionScopes
Returns the scopes of the async arrow function.
Sourcepub const fn linear_span(&self) -> LinearSpan
pub const fn linear_span(&self) -> LinearSpan
Gets linear span of the function declaration.
Sourcepub const fn contains_direct_eval(&self) -> bool
pub const fn contains_direct_eval(&self) -> bool
Returns true if the function declaration contains a direct call to eval.