pub struct ClassExpression { /* private fields */ }Expand description
Implementations
Sourceimpl ClassExpression
impl ClassExpression
Sourcepub fn new(
name: Option<Identifier>,
super_ref: Option<Expression>,
constructor: Option<FunctionExpression>,
elements: Box<[ClassElement]>,
has_binding_identifier: bool,
span: Span,
) -> Self
pub fn new( name: Option<Identifier>, super_ref: Option<Expression>, constructor: Option<FunctionExpression>, elements: Box<[ClassElement]>, has_binding_identifier: bool, span: Span, ) -> Self
Creates a new class expression.
Sourcepub const fn name(&self) -> Option<Identifier>
pub const fn name(&self) -> Option<Identifier>
Returns the name of the class expression.
Sourcepub const fn super_ref(&self) -> Option<&Expression>
pub const fn super_ref(&self) -> Option<&Expression>
Returns the super class ref of the class expression.
Sourcepub const fn constructor(&self) -> Option<&FunctionExpression>
pub const fn constructor(&self) -> Option<&FunctionExpression>
Returns the constructor of the class expression.
Sourcepub const fn elements(&self) -> &[ClassElement]
pub const fn elements(&self) -> &[ClassElement]
Gets the list of all fields defined on the class expression.
Sourcepub const fn name_scope(&self) -> Option<&Scope>
pub const fn name_scope(&self) -> Option<&Scope>
Gets the scope containing the class name binding if it exists.