pub struct ClassMethodDefinition { /* private fields */ }Expand description
A method definition.
This type is specific to class method definitions. It includes private names and the information about whether the method is static or not.
More information:
Implementations
Sourceimpl ClassMethodDefinition
impl ClassMethodDefinition
Sourcepub fn new(
name: ClassElementName,
parameters: FormalParameterList,
body: FunctionBody,
kind: MethodDefinitionKind,
is_static: bool,
start_linear_pos: LinearPosition,
) -> Self
pub fn new( name: ClassElementName, parameters: FormalParameterList, body: FunctionBody, kind: MethodDefinitionKind, is_static: bool, start_linear_pos: LinearPosition, ) -> Self
Creates a new class method definition.
Sourcepub const fn name(&self) -> &ClassElementName
pub const fn name(&self) -> &ClassElementName
Returns the name of the class method definition.
Sourcepub const fn parameters(&self) -> &FormalParameterList
pub const fn parameters(&self) -> &FormalParameterList
Returns the parameters of the class method definition.
Sourcepub const fn body(&self) -> &FunctionBody
pub const fn body(&self) -> &FunctionBody
Returns the body of the class method definition.
Sourcepub const fn kind(&self) -> MethodDefinitionKind
pub const fn kind(&self) -> MethodDefinitionKind
Returns the kind of the class method definition.
Sourcepub const fn is_private(&self) -> bool
pub const fn is_private(&self) -> bool
Returns whether the class method definition is private.
Sourcepub const fn scopes(&self) -> &FunctionScopes
pub const fn scopes(&self) -> &FunctionScopes
Gets the scopes of the class method definition.
Sourcepub const fn linear_span(&self) -> LinearSpan
pub const fn linear_span(&self) -> LinearSpan
Gets linear span of the function declaration.
Sourcepub const fn contains_direct_eval(&self) -> bool
pub const fn contains_direct_eval(&self) -> bool
Returns true if the class method definition contains a direct call to eval.