pub struct FormalParameter { /* private fields */ }Expand description
“Formal parameter” is a fancy way of saying “function parameter”.
In the declaration of a function, the parameters must be identifiers, not any value like numbers, strings, or objects.
function foo(formalParameter1, formalParameter2) {
}More information:
Implementations
Sourceimpl FormalParameter
impl FormalParameter
Sourcepub const fn init(&self) -> Option<&Expression>
pub const fn init(&self) -> Option<&Expression>
Gets the initialization node of the formal parameter, if any.
Sourcepub const fn is_rest_param(&self) -> bool
pub const fn is_rest_param(&self) -> bool
Returns true if the parameter is a rest parameter.
Sourcepub const fn is_identifier(&self) -> bool
pub const fn is_identifier(&self) -> bool
Returns true if the parameter is an identifier.