pub struct FunctionDeclaration { /* private fields */ }Expand description
Implementations
Sourceimpl FunctionDeclaration
impl FunctionDeclaration
Sourcepub fn new(
name: Identifier,
parameters: FormalParameterList,
body: FunctionBody,
linear_span: LinearSpan,
) -> Self
pub fn new( name: Identifier, parameters: FormalParameterList, body: FunctionBody, linear_span: LinearSpan, ) -> Self
Creates a new function declaration.
Sourcepub const fn name(&self) -> Identifier
pub const fn name(&self) -> Identifier
Gets the name of the function declaration.
Sourcepub const fn parameters(&self) -> &FormalParameterList
pub const fn parameters(&self) -> &FormalParameterList
Gets the list of parameters of the function declaration.
Sourcepub const fn body(&self) -> &FunctionBody
pub const fn body(&self) -> &FunctionBody
Gets the body of the function declaration.
Sourcepub const fn scopes(&self) -> &FunctionScopes
pub const fn scopes(&self) -> &FunctionScopes
Gets the scopes of the function declaration.
Sourcepub const fn linear_span(&self) -> LinearSpan
pub const fn linear_span(&self) -> LinearSpan
Gets linear span of the function declaration.
Sourcepub const fn contains_direct_eval(&self) -> bool
pub const fn contains_direct_eval(&self) -> bool
Returns true if the function declaration contains a direct call to eval.