pub struct FunctionExpression { /* private fields */ }Expand description
Implementations
Sourceimpl FunctionExpression
impl FunctionExpression
Sourcepub fn new(
name: Option<Identifier>,
parameters: FormalParameterList,
body: FunctionBody,
linear_span: Option<LinearSpan>,
has_binding_identifier: bool,
span: Span,
) -> Self
pub fn new( name: Option<Identifier>, parameters: FormalParameterList, body: FunctionBody, linear_span: Option<LinearSpan>, has_binding_identifier: bool, span: Span, ) -> Self
Creates a new function expression.
Sourcepub const fn name(&self) -> Option<Identifier>
pub const fn name(&self) -> Option<Identifier>
Gets the name of the function expression.
Sourcepub const fn parameters(&self) -> &FormalParameterList
pub const fn parameters(&self) -> &FormalParameterList
Gets the list of parameters of the function expression.
Sourcepub const fn body(&self) -> &FunctionBody
pub const fn body(&self) -> &FunctionBody
Gets the body of the function expression.
Sourcepub const fn has_binding_identifier(&self) -> bool
pub const fn has_binding_identifier(&self) -> bool
Returns whether the function expression has a binding identifier.
Sourcepub const fn name_scope(&self) -> Option<&Scope>
pub const fn name_scope(&self) -> Option<&Scope>
Gets the name scope of the function expression.
Sourcepub const fn scopes(&self) -> &FunctionScopes
pub const fn scopes(&self) -> &FunctionScopes
Gets the scopes of the function expression.
Sourcepub const fn linear_span(&self) -> Option<LinearSpan>
pub const fn linear_span(&self) -> Option<LinearSpan>
Gets linear span of the function declaration.
Sourcepub const fn contains_direct_eval(&self) -> bool
pub const fn contains_direct_eval(&self) -> bool
Returns true if the function expression contains a direct call to eval.