pub enum CheckLabelsError {
DuplicateLabel(Sym),
UndefinedBreakTarget(Sym),
UndefinedContinueTarget(Sym),
IllegalBreakStatement,
IllegalContinueStatement,
}Expand description
Errors that can occur when checking labels.
Variants
DuplicateLabel(Sym)
A label was used multiple times.
UndefinedBreakTarget(Sym)
A break statement was used with a label that was not defined.
UndefinedContinueTarget(Sym)
A continue statement was used with a label that was not defined.
IllegalBreakStatement
A break statement was used in a non-looping context.
IllegalContinueStatement
A continue statement was used in a non-looping context.
Implementations