pub enum BindingLocatorScope {
GlobalObject,
GlobalDeclarative,
Stack(u32),
}Expand description
The scope in which a binding is located.
Variants
GlobalObject
The binding is located on the global object.
GlobalDeclarative
The binding is located in the global declarative scope.
Stack(u32)
The binding is located in the scope stack at the given index.