BindingLocator

Struct BindingLocator 

pub struct BindingLocator { /* private fields */ }
A binding locator contains all information about a binding that is needed to resolve it at runtime.

Implementations

Source

impl BindingLocator

pub const fn name(&self) -> &JsString

Returns the name of the binding.

pub const fn is_global(&self) -> bool

Returns if the binding is located on the global object.

pub fn scope(&self) -> BindingLocatorScope

Returns the scope of the binding.

pub fn set_scope(&mut self, scope: BindingLocatorScope)

Sets the scope of the binding.

pub const fn binding_index(&self) -> u32

Returns the binding index of the binding.

pub fn set_binding_index(&mut self, index: u32)

Sets the binding index of the binding.

pub fn unique_scope_id(&self) -> u32

Returns the unique scope ID of the binding.