Scope

Struct Scope 

pub struct Scope { /* private fields */ }
A scope maps bound identifiers to their binding positions.

It can be either a global scope or a function scope or a declarative scope.

Implementations

Source

impl Scope

pub fn new_global() -> Self

Creates a new global scope.

pub fn new(parent: Self, function: bool) -> Self

Creates a new scope.

pub fn all_bindings_local(&self) -> bool

Checks if the scope has only local bindings.

pub fn escape_all_bindings(&self)

Marks all bindings in this scope as escaping.

pub fn escaped_this(&self) -> bool

Has this binding escaped.

pub fn has_lex_binding(&self, name: &JsString) -> bool

Check if the scope has a lexical binding with the given name.

pub fn has_binding(&self, name: &JsString) -> bool

Check if the scope has a binding with the given name.

pub fn get_identifier_reference(&self, name: JsString) -> IdentifierReference

Get the binding locator for a binding with the given name. Fall back to the global scope if the binding is not found.

pub fn num_bindings(&self) -> u32

Returns the number of bindings in this scope.

pub fn num_bindings_non_local(&self) -> u32

Returns the number of bindings in this scope that are not local.

pub fn scope_index(&self) -> u32

Returns the index of this scope.

pub fn is_function(&self) -> bool

Check if the scope is a function scope.

pub fn is_global(&self) -> bool

Check if the scope is a global scope.

pub fn is_binding_mutable(&self, name: &JsString) -> Option<bool>

Check if a binding with the given name is mutable.

Returns Some(true) for mutable bindings (let, var), Some(false) for immutable bindings (const), or None if the binding is not found in this or any outer scope.

pub fn get_binding(&self, name: &JsString) -> Option<BindingLocator>

Get the locator for a binding name.

pub fn get_binding_reference( &self, name: &JsString, ) -> Option<IdentifierReference>

Get the locator for a binding name.

pub fn access_binding(&self, name: &JsString, eval_or_with: bool)

Simulate a binding access.

  • If the binding access crosses a function border, the binding is marked as escaping.
  • If the binding access is in an eval or with scope, the binding is marked as escaping.
pub fn escape_this_in_enclosing_function_scope(&self)

Escape enclosing function environment’s this.

pub fn create_mutable_binding( &self, name: JsString, function_scope: bool, ) -> BindingLocator

Creates a mutable binding.

pub fn set_mutable_binding( &self, name: JsString, ) -> Result<IdentifierReference, BindingLocatorError>

Return the binding locator for a mutable binding.

Errors

Returns an error if the binding is not mutable or does not exist.

pub fn set_mutable_binding_var( &self, name: JsString, ) -> Result<IdentifierReference, BindingLocatorError>

Return the binding locator for a set operation on an existing var binding.

Errors

Returns an error if the binding is not mutable or does not exist.

pub fn outer(&self) -> Option<&Self>

Gets the outer scope of this scope.

pub fn unique_id(&self) -> u32

Returns the unique ID of this scope.