LabelledItem

Enum LabelledItem 

pub enum LabelledItem {
    FunctionDeclaration(FunctionDeclaration),
    Statement(Statement),
}
The set of Parse Nodes that can be preceded by a label, as defined by the spec.

Semantically, a Labelled statement should only wrap Statement nodes. However, old ECMAScript implementations supported labelled function declarations as an extension of the grammar. In the ECMAScript 2015 spec, the production of LabelledStatement was modified to include labelled FunctionDeclarations as a valid node.

Variants



FunctionDeclaration(FunctionDeclaration)

A labelled FunctionDeclaration.



Statement(Statement)

A labelled Statement.