IterableLoopInitializer

Enum IterableLoopInitializer 

pub enum IterableLoopInitializer {
    Identifier(Identifier),
    Access(PropertyAccess),
    Var(Variable),
    Let(Binding),
    Const(Binding),
    Pattern(Pattern),
}
A for-in, for-of and for-await-of loop initializer.

The spec specifies only single bindings for the listed types of loops, which makes us unable to use plain LexicalDeclarations or VarStatements as initializers, since those can have more than one binding.

Variants



Identifier(Identifier)

An already declared variable.



Access(PropertyAccess)

A property access.



Var(Variable)

A new var declaration.



Let(Binding)

A new let declaration.



Const(Binding)

A new const declaration.



Pattern(Pattern)

A pattern with already declared variables.