Continue

Struct Continue 

pub struct Continue { /* private fields */ }
The continue statement terminates execution of the statements in the current iteration of the current or labeled loop, and continues execution of the loop with the next iteration.

The continue statement can include an optional label that allows the program to jump to the next iteration of a labeled loop statement instead of the current loop. In this case, the continue statement needs to be nested within this labeled statement.

More information:

Implementations

Source

impl Continue

pub const fn new(label: Option<Sym>) -> Self

Creates a Continue AST node.

pub const fn label(&self) -> Option<Sym>

Gets the label of this Continue statement.