pub struct ForLoop { /* private fields */ }Expand description
The for statement creates a loop that consists of three optional expressions.
A for loop repeats until a specified condition evaluates to false.
The JavaScript for loop is similar to the Java and C for loop.
More information:
Implementations
Sourceimpl ForLoop
impl ForLoop
Sourcepub fn new(
init: Option<ForLoopInitializer>,
condition: Option<Expression>,
final_expr: Option<Expression>,
body: Statement,
) -> Self
pub fn new( init: Option<ForLoopInitializer>, condition: Option<Expression>, final_expr: Option<Expression>, body: Statement, ) -> Self
Creates a new for loop AST node.
Sourcepub const fn init(&self) -> Option<&ForLoopInitializer>
pub const fn init(&self) -> Option<&ForLoopInitializer>
Gets the initialization node.
Sourcepub const fn condition(&self) -> Option<&Expression>
pub const fn condition(&self) -> Option<&Expression>
Gets the loop condition node.
Sourcepub const fn final_expr(&self) -> Option<&Expression>
pub const fn final_expr(&self) -> Option<&Expression>
Gets the final expression node.