Block

Struct Block 

pub struct Block { /* private fields */ }
A block statement (or compound statement in other languages) is used to group zero or more statements.

The block statement is often called compound statement in other languages. It allows you to use multiple statements where ECMAScript expects only one statement. Combining statements into blocks is a common practice in ECMAScript. The opposite behavior is possible using an empty statement, where you provide no statement, although one is required.

More information:

Implementations

Source

impl Block

pub const fn statement_list(&self) -> &StatementList

Gets the list of statements and declarations in this block.

pub const fn scope(&self) -> Option<&Scope>

Gets the scope of the block.