pub struct LinearSpan { /* private fields */ }Expand description
A linear span in the ECMAScript source code.
Stores a linear start position and a linear end position.
Note that linear spans are of the form [start, end) i.e. that the start position is inclusive and the end position is exclusive.
Implementations
Sourceimpl LinearSpan
impl LinearSpan
Sourcepub const fn new(start: LinearPosition, end: LinearPosition) -> Self
pub const fn new(start: LinearPosition, end: LinearPosition) -> Self
Sourcepub const fn start(self) -> LinearPosition
pub const fn start(self) -> LinearPosition
Gets the starting position of the span.
Sourcepub const fn end(self) -> LinearPosition
pub const fn end(self) -> LinearPosition
Gets the final position of the span.