pub struct Position { /* private fields */ }Expand description
A position in the ECMAScript source code.
Stores both the column number and the line number.
Similar Implementations
Implementations
Sourceimpl Position
impl Position
Sourcepub const fn new(line_number: u32, column_number: u32) -> Self
pub const fn new(line_number: u32, column_number: u32) -> Self
Creates a new Position from Non-Zero values.
Panics
Will panic if the line number or column number is zero.
Sourcepub const fn line_number(self) -> u32
pub const fn line_number(self) -> u32
Gets the line number of the position.
Sourcepub const fn column_number(self) -> u32
pub const fn column_number(self) -> u32
Gets the column number of the position.