Span

Struct Span 

pub struct Span { /* private fields */ }
A span in the ECMAScript source code.

Stores a start position and an end position.

Note that spans are of the form [start, end) i.e. that the start position is inclusive and the end position is exclusive.

Implementations

Source

impl Span

pub fn new<T, U>(start: T, end: U) -> Self
where T: Into<Position>, U: Into<Position>,

Creates a new Span.

Panics

Panics if the start position is bigger than the end position.

pub const fn start(self) -> Position

Gets the starting position of the span.

pub const fn end(self) -> Position

Gets the final position of the span.

pub fn contains<S>(self, other: S) -> bool
where S: Into<Self>,

Checks if this span inclusively contains another span or position.