pub enum ImportKind {
DefaultOrUnnamed,
Namespaced {
binding: Identifier,
},
Named {
names: Box<[ImportSpecifier]>,
},
}Expand description
The kind of import in an ImportDeclaration.
Variants
DefaultOrUnnamed
Default (import defaultName from "module-name") or unnamed (import "module-name").
Namespaced
Namespaced import (import * as name from "module-name").
Fields

binding: IdentifierBinding for the namespace created from the exports of the imported module.
Named
Import list (import { export1, export2 as alias2 } from "module-name").
Fields

names: Box<[ImportSpecifier]>List of the required exports of the imported module.