pub struct Binary { /* private fields */ }Expand description
Binary operations require two operands, one before the operator and one after the operator.
See the module level documentation for more information.
Implementations
Sourceimpl Binary
impl Binary
Sourcepub fn new(op: BinaryOp, lhs: Expression, rhs: Expression) -> Self
pub fn new(op: BinaryOp, lhs: Expression, rhs: Expression) -> Self
Creates a BinOp AST Expression.
Sourcepub const fn lhs(&self) -> &Expression
pub const fn lhs(&self) -> &Expression
Gets the left hand side of the binary operation.
Sourcepub const fn rhs(&self) -> &Expression
pub const fn rhs(&self) -> &Expression
Gets the right hand side of the binary operation.
Sourcepub fn lhs_mut(&mut self) -> &mut Expression
pub fn lhs_mut(&mut self) -> &mut Expression
Gets the left hand side of the binary operation.
Sourcepub fn rhs_mut(&mut self) -> &mut Expression
pub fn rhs_mut(&mut self) -> &mut Expression
Gets the right hand side of the binary operation.