pub struct TaggedTemplate { /* private fields */ }Expand description
A TaggedTemplate expression, as defined by the spec.
TaggedTemplates are a type of template literals that are parsed by a custom function to generate
arbitrary objects from the inner strings and expressions.
Implementations
Sourceimpl TaggedTemplate
impl TaggedTemplate
Sourcepub fn new(
tag: Expression,
raws: Box<[Sym]>,
cookeds: Box<[Option<Sym>]>,
exprs: Box<[Expression]>,
identifier: u64,
span: Span,
) -> Self
pub fn new( tag: Expression, raws: Box<[Sym]>, cookeds: Box<[Option<Sym>]>, exprs: Box<[Expression]>, identifier: u64, span: Span, ) -> Self
Creates a new tagged template with a tag, the list of raw strings, the cooked strings and the expressions.
Sourcepub const fn tag(&self) -> &Expression
pub const fn tag(&self) -> &Expression
Gets the tag function of the template.
Sourcepub const fn exprs(&self) -> &[Expression]
pub const fn exprs(&self) -> &[Expression]
Gets the interpolated expressions of the template.
Sourcepub const fn identifier(&self) -> u64
pub const fn identifier(&self) -> u64
Gets the unique identifier of the template.