pub struct FormalParameterList { /* private fields */ }Expand description
A list of FormalParameters that describes the parameters of a function, as defined by the spec.
Implementations
Sourceimpl FormalParameterList
impl FormalParameterList
Sourcepub fn from_parameters(parameters: Vec<FormalParameter>) -> Self
pub fn from_parameters(parameters: Vec<FormalParameter>) -> Self
Creates a FormalParameterList from a list of FormalParameters.
Sourcepub const fn length(&self) -> u32
pub const fn length(&self) -> u32
Returns the length of the parameter list. Note that this is not equal to the length of the parameters slice.
Sourcepub const fn flags(&self) -> FormalParameterListFlags
pub const fn flags(&self) -> FormalParameterListFlags
Returns the parameter list flags.
Sourcepub const fn has_duplicates(&self) -> bool
pub const fn has_duplicates(&self) -> bool
Indicates if the parameter list has duplicate parameters.
Sourcepub const fn has_rest_parameter(&self) -> bool
pub const fn has_rest_parameter(&self) -> bool
Indicates if the parameter list has a rest parameter.
Sourcepub const fn has_expressions(&self) -> bool
pub const fn has_expressions(&self) -> bool
Indicates if the parameter list has expressions in it’s parameters.
Sourcepub const fn has_arguments(&self) -> bool
pub const fn has_arguments(&self) -> bool
Indicates if the parameter list has parameters named ‘arguments’.