FunctionScopes

Struct FunctionScopes 

pub struct FunctionScopes { /* private fields */ }
A collection of function scopes.

Implementations

Source

impl FunctionScopes

pub fn function_scope(&self) -> &Scope

Returns the function scope for this function.

pub fn arguments_object_accessed(&self) -> bool

Returns if the arguments object is accessed in this function.

pub fn requires_function_scope(&self) -> bool

Check if the creation of the function scope is required.

pub fn parameters_eval_scope(&self) -> Option<&Scope>

Returns the parameters eval scope for this function.

pub fn parameters_scope(&self) -> Option<&Scope>

Returns the parameters scope for this function.

pub fn lexical_scope(&self) -> Option<&Scope>

Returns the lexical scope for this function.

pub fn parameter_scope(&self) -> Scope

Returns the effective parameter scope for this function.