Statement

Enum Statement 

pub enum Statement {
Show 19 variants Block(Block), Var(VarDeclaration), Empty, Expression(Expression), If(If), DoWhileLoop(DoWhileLoop), WhileLoop(WhileLoop), ForLoop(ForLoop), ForInLoop(ForInLoop), ForOfLoop(ForOfLoop), Switch(Switch), Continue(Continue), Break(Break), Return(Return), Labelled(Labelled), Throw(Throw), Try(Try), With(With), Debugger,
}
The Statement Parse Node.

See the module level documentation for more information.

Variants



Block(Block)

See Block.



Var(VarDeclaration)



Empty

An empty statement.

Empty statements do nothing, just return undefined.

More information:



Expression(Expression)



If(If)

See If.



DoWhileLoop(DoWhileLoop)



WhileLoop(WhileLoop)

See WhileLoop.



ForLoop(ForLoop)

See ForLoop.



ForInLoop(ForInLoop)

See ForInLoop.



ForOfLoop(ForOfLoop)

See ForOfLoop.



Switch(Switch)

SeeSwitch.



Continue(Continue)

See Continue.



Break(Break)

See Break.



Return(Return)

See Return.



Labelled(Labelled)

See Labelled.



Throw(Throw)

See Throw.



Try(Try)

See Try.



With(With)

See With.



Debugger

A debugger statement.

The debugger statement invokes any available debugging functionality.

More information:

Implementations

Source

impl Statement

pub fn is_labelled_function(&self) -> bool

Abstract operation IsLabelledFunction.

This recursively checks if this Statement is a labelled function, since adding several labels in a function should not change the return value of the abstract operation:

l1: l2: l3: l4: function f(){ }

This should return true for that snippet.